@@ -4,7 +4,7 @@ from SciDataTool.Functions.interpolations import get_common_base
 from SciDataTool.Functions.symmetries import rebuild_symmetries_axis
 from SciDataTool.Classes.DataPattern import DataPattern
 from SciDataTool.Functions import AxisError
-from numpy import array
+from numpy import array, ndarray
 from importlib import import_module
 
 
@@ -24,8 +24,11 @@ def get_axis(self, axis, is_real):
     is_components = getattr(axis, "is_components", False)
     if is_components:
         values = axis.get_values()
-        if not self.extension in ["sum", "rss", "mean", "rms"]:
+        if not self.extension in ["sum", "rss", "mean", "rms", "integrate"]:
             self.extension = "list"
+        if self.input_data is not None:
+            self.indices = self.input_data.tolist()
+            self.input_data = None
         if self.indices is not None:
             self.values = values[self.indices]
         else:
@@ -68,12 +71,12 @@ def get_axis(self, axis, is_real):
                 is_smallestperiod = False
                 is_oneperiod = True
                 is_antiperiod = False
-        elif self.extension in ["sum", "rss", "mean", "rms"]:
+        elif self.extension in ["sum", "rss", "mean", "rms", "integrate"]:
             is_smallestperiod = False
             is_oneperiod = False
             is_antiperiod = False
         else:
-            if self.input_data is not None:
+            if self.input_data is not None and not self.is_step:
                 axis_values = axis.get_values(is_smallestperiod=True)
                 if min(self.input_data) >= min(axis_values) and max(
                     self.input_data
@@ -133,8 +136,10 @@ def get_axis(self, axis, is_real):
         elif unit in axis.normalizations:
             if axis.normalizations.get(unit) == "indices":
                 values = array([i for i in range(len(values))])
+            elif isinstance(axis.normalizations.get(unit), ndarray):
+                values = axis.normalizations.get(unit)
             else:
-                values = array([v / axis.normalizations.get(unit) for v in values])
+                values = values / axis.normalizations.get(unit)
         else:
             values = convert(values, self.corr_unit, unit)
         # Rebuild symmetries in fft case
@@ -165,6 +170,8 @@ def get_axis(self, axis, is_real):
         if self.input_data is None:
             self.values = values
         else:
+            # if self.is_step:
+            #     values = values[axis.rebuild_indices]
             if len(self.input_data) == 2 and self.extension != "axis_data":
                 indices = [
                     i
@@ -181,17 +188,8 @@ def get_axis(self, axis, is_real):
                     self.indices = indices_new
                 self.input_data = None
             else:
-                if self.extension == "axis_data":
-                    # if self.is_step:
-                    self.input_data = self.input_data
-                    # else:
-                    #     self.input_data = get_common_base(
-                    #         self.input_data, values, is_downsample=True
-                    #     )
-                else:
-                    self.input_data = get_common_base(self.input_data, values)
                 self.values = values
         if self.indices is not None:
             self.values = values[self.indices]
-            if self.extension in ["sum", "rss", "mean", "rms"]:
+            if self.extension in ["sum", "rss", "mean", "rms", "integrate"]:
                 self.indices = None
